@@ -8,4 +8,6 @@ pub enum Error {
     Channel,
     PacketPayload,
     TlsAcceptTimeout,
+    NoDelayError,
+    TlsAccept,
 }
