@@ -44,7 +44,7 @@ impl GameLoop {
 
     fn get_sleep_time(&self) -> i64 {
         let new_date = chrono::offset::Local::now();
-        let execution_diff = new_date.timestamp_millis() - self.date.load(Ordering::SeqCst);
+        let execution_diff = new_date.timestamp_millis() - self.date.load(Ordering::Acquire);
 
         if self.interval > execution_diff {
             self.interval - execution_diff
@@ -53,8 +53,7 @@ impl GameLoop {
         }
     }
 
-    fn get_diff(old: i64, current: i64) -> i64 {
-        debug_assert!(current >= old);
+    const fn get_diff(old: i64, current: i64) -> i64 {
         if old >= current {
             0
         } else {
@@ -64,7 +63,7 @@ impl GameLoop {
 
     fn update_game_time(&mut self) -> i64 {
         let current = chrono::offset::Local::now().timestamp_millis();
-        self.date.store(current, Ordering::SeqCst);
+        self.date.store(current, Ordering::Release);
 
         current
     }
@@ -84,7 +83,7 @@ impl GameLoop {
 mod tests {
     use std::{sync::Arc, time::Instant};
 
-    use crate::server::{dos_protection::DosPolicy, world::WorldTime, world_session::WorldSession};
+    use crate::server::{world::WorldTime, world_session::WorldSession};
 
     use super::*;
     use async_trait::async_trait;
@@ -133,7 +132,7 @@ mod tests {
     async fn test_update_time() {
         let mut game_loop = GameLoop::new(Duration::from_millis(25));
         sleep(Duration::from_millis(10)).await;
-        let old = game_loop.date.load(Ordering::SeqCst);
+        let old = game_loop.date.load(Ordering::Acquire);
         let new_date = game_loop.update_game_time();
         assert!(old != new_date && new_date > old);
     }
@@ -142,7 +141,9 @@ mod tests {
     #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
     async fn test_loop() {
         let mut game_loop = GameLoop::new(Duration::from_millis(25));
-        let world = Box::new(TestGameLoop);
+        let world = Box::new(TestGameLoop {
+            time: AtomicI64::new(0),
+        });
         let world = Box::leak(world);
         tokio::time::timeout(Duration::from_secs(1), game_loop.start(world))
             .await
@@ -181,16 +182,11 @@ mod tests {
         async fn on_close(_world_session: &Arc<Self>, _world: &'static TestGameLoop) {
             todo!()
         }
-
-        async fn on_dos_trigger(
-            _world_session: &Arc<Self>,
-            _world: &'static TestGameLoop,
-            _cmd: u16,
-        ) {
-        }
     }
 
-    struct TestGameLoop;
+    struct TestGameLoop {
+        time: AtomicI64,
+    }
 
     impl World for TestGameLoop {
         type WorldSessionimplementer = SessionTest;
@@ -198,17 +194,16 @@ mod tests {
         fn update(&'static self, _diff: i64) {
             panic!("Test : update");
         }
-
-        fn get_packet_limits(&self, _cmd: u16) -> (u16, u32, DosPolicy) {
-            (100, 1024 * 10, DosPolicy::Log)
-        }
     }
 
     impl WorldTime for TestGameLoop {
         fn time(&self) -> i64 {
-            10
+            self.time.load(Ordering::Acquire)
         }
 
-        fn update_time(&self, _new_time: i64) {}
+        fn update_time(&self, new_time: i64) {
+            self.time.store(new_time, Ordering::Release);
+            assert_ne!(10, new_time);
+        }
     }
 }
