@@ -4,6 +4,7 @@ macro_rules! cfg_server {
     ($($item:item)*) => {
         $(
             #[cfg(feature = "server")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "server")))]
             $item
         )*
     }
@@ -13,6 +14,7 @@ macro_rules! cfg_macros {
     ($($item:item)*) => {
         $(
             #[cfg(feature = "macros")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "macros")))]
             $item
         )*
     }
@@ -22,15 +24,17 @@ macro_rules! cfg_game {
     ($($item:item)*) => {
         $(
             #[cfg(feature = "game")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "game")))]
             $item
         )*
     }
 }
 
-macro_rules! cfg_flat_buffers_helpers {
+macro_rules! cfg_flatbuffers_helpers {
     ($($item:item)*) => {
         $(
-            #[cfg(feature = "flat_buffers_helpers")]
+            #[cfg(feature = "flatbuffers_helpers")]
+            #[cfg_attr(docsrs, doc(cfg(feature = "flatbuffers_helpers")))]
             $item
         )*
     }
